@@ -56,7 +56,6 @@ class Server:
             return
         def clientTask(clientSocket, address):
             logger.log("§8[§eSERVER§8] §aClient connected from §6" + str(address))
-            lastData = ""
             error = False
             if self.enabled_whitelist_ip is True:
                 if address[0] not in self.whitelisted_ips:
@@ -64,20 +63,10 @@ class Server:
                     logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cIp-Address §6'" + str(address[0]) + "'§c not whitelisted!")
             while error is False:
                 try:
-                    recvData = clientSocket.recv(32768)
+                    data_length = int(clientSocket.recv(128))
+                    recvData = clientSocket.recv(data_length)
                     recvData = str(recvData, "utf-8")
                     if recvData != "":
-                        if not recvData.startswith("{"):
-                            if recvData.endswith("}" + self.seq):
-                                if lastData != "":
-                                    recvData = lastData + recvData
-                                    if self.printUnsignedData:
-                                        logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cUnsigned data repaired")
-                        if not recvData.endswith("}" + self.seq):
-                            lastData += recvData
-                            if self.printUnsignedData:
-                                logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cReceiving unsigned data: §r" + recvData)
-                            continue
                         if "}" + self.seq + "{" in recvData:
                             recvDataList = recvData.split("}" + self.seq + "{")
                             recvData = "["
@@ -91,13 +80,15 @@ class Server:
                                     if i + 1 < len(recvDataList):
                                         recvData += "}, {"
                             recvData += "]"
-                            lastData = ""
                         elif "}" + self.seq in recvData:
                             if self.enabled_encrypt is True:
                                 recvData = "[" + crypthography.decrypt(self.secret_key, base64.b64decode(recvData.replace("}" + self.seq, "")[1:].encode('ascii'))).decode("utf-8") + "]"
                             else:
                                 recvData = "[" + recvData.replace(self.seq, "") + "]"
-                            lastData = ""
+                        else:
+                            if self.printUnsignedData:
+                                logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cReceiving unsigned data: §r" + recvData)
+                            continue
                         try:
                             recvData = json.loads(recvData)
                         except Exception:
@@ -143,7 +134,7 @@ class Server:
                                 else:
                                     logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cReceiving not authenticated package: §r" + data["METHOD"])
                 except Exception as e:
-                    if "Connection reset by peer" in str(e): break
+                    if "Connection reset by peer" in str(e) or "Connection timed out" in str(e): break
                     if self.uploadError is True:
                         try:
                             link = dev.uploadToHastebin(traceback.format_exc())
@@ -160,11 +151,13 @@ class Server:
                     p = False
             try: self.clientSocks.remove(clientSocket)
             except: pass
-            clientSocket.close()
+            try: clientSocket.close()
+            except: pass
             if p is True: logger.log("§8[§eSERVER§8] §6Client " + str(address) + " disconnected")
 
         while True:
             (client, clientAddress) = self.serverSocket.accept()
+            client.settimeout(60)
             self.clientSocks.append(client)
             Thread(target=clientTask, args=[client, clientAddress]).start()
 
@@ -195,7 +188,10 @@ class Server:
             send_data = json.dumps(data)
             if self.enabled_encrypt is True:
                 send_data = "{" + base64.b64encode(crypthography.encrypt(self.secret_key, send_data)).decode('utf-8') + "}"
-            sock.send(bytes(send_data + self.seq, "utf-8"))
+            send_data = bytes(send_data + self.seq, "utf-8")
+            data_length = len(send_data)
+            sock.send(bytes(str(data_length) + " " * (128 - len(str(data_length))), "utf-8"))
+            sock.send(send_data)
             if data["METHOD"] not in self.packagePrintBlacklist:
                 logger.log("§8[§eSERVER§8] §r[OUT] " + data["METHOD"])
         except Exception as e:
@@ -210,7 +206,8 @@ class Server:
                         p = False
                 try: self.clientSocks.remove(sock)
                 except: pass
-                sock.close()
+                try: sock.close()
+                except: pass
                 if p is True: logger.log("§8[§eSERVER§8] §6Client disconnected")
 
     def sendToClientID(self, clientID, data):
